==> haskell-emojis-0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 emojis
version:              0.1
visibility:           public
id:                   emojis-0.1-5bKZuazWqDFIPJwD9l5Co3
key:                  emojis-0.1-5bKZuazWqDFIPJwD9l5Co3
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  c4b054d273859da918dbd54733370a8c
exposed:              True
exposed-modules:      Text.Emoji
import-dirs:          /usr/lib/ghc-8.10.1/site-local/emojis-0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/emojis-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/emojis-0.1
hs-libraries:         HSemojis-0.1-5bKZuazWqDFIPJwD9l5Co3
depends:              base-4.14.0.0 containers-0.6.2.1 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-emojis-0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-emojis.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 emojis
version:              0.1
visibility:           public
id:                   emojis-0.1-BDdRpBxKwDsHR5arAgaKZh
key:                  emojis-0.1-BDdRpBxKwDsHR5arAgaKZh
license:              BSD-3-Clause
copyright:            2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/emojis#readme
synopsis:             Conversion between emoji characters and their names.
description:
    This package provides functions for converting
    emoji names to emoji characters and vice versa.

    How does it differ from the @emoji@ package?

    -   It supports a fuller range of emojis, including all those
    supported by GitHub
    -   It supports lookup of emoji aliases from emoji
    -   It uses Text rather than String
    -   It has a lighter dependency footprint: in particular, it
    does not require aeson
    -   It does not require TemplateHaskell

category:             Text
abi:                  35acb2c8f2023f9a603ec6f3c692cbf1
exposed:              True
exposed-modules:      Text.Emoji
import-dirs:          /usr/lib/ghc-8.10.1/site-local/emojis-0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/emojis-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/emojis-0.1
hs-libraries:         HSemojis-0.1-BDdRpBxKwDsHR5arAgaKZh
depends:              base-4.14.0.0 containers-0.6.2.1 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-emojis/html/emojis.haddock
haddock-html:         /usr/share/doc/haskell-emojis/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
